AmbiguousKeyError class

An error that occurs when a key exists in multiple boxes and no specific box is specified.

When calling get() without specifying a box parameter, if the key exists in more than one box (including default normal/secure boxes and custom boxes), this error is thrown to prevent ambiguity.

Inheritance

Constructors

AmbiguousKeyError(String key, List<String> foundInBoxes, String message, [Object? originalException])
Creates a new AmbiguousKeyError.
const

Properties

foundInBoxes List<String>
The names of the boxes where the key was found.
final
hashCode int
The hash code for this object.
no setterinherited
key String
The key that exists in multiple boxes.
final
message String
A descriptive message explaining the nature of the error.
finalinherited
originalException Object?
The original exception or error object that was caught, if any.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited