EmulatorDetectedException class
Exception thrown when emulator is detected
Only thrown on Android and iOS platforms where FreeRASP can detect virtual device environments. Never thrown on other platforms.
- Inheritance
-
- Object
- SecurityThreatException
- EmulatorDetectedException
Constructors
- EmulatorDetectedException([Object? cause])
-
const
Properties
- cause → Object?
-
The underlying cause of the exception, if any
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Detailed message about the security threat
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threatType → String
-
The type of security threat that was detected
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited